@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -33,7 +33,7 @@ namespace ps {
         void record(const char** argv, const char** envp) const;
         void context() const;
 
-        NON_DEFAULT_CONSTRUCTABLE(ApplicationLogConfig);
+        NON_DEFAULT_CONSTRUCTABLE(ApplicationLogConfig)
 
     protected:
         const char *name_;
